@@ -1,5 +1,5 @@
 #
-# Copyright 2012-2021 Ghent University
+# Copyright 2012-2022 Ghent University
 #
 # This file is part of vsc-base,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -35,6 +35,7 @@ import logging
 import re
 import smtplib
 import ssl
+from configparser import ConfigParser
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.mime.image import MIMEImage
@@ -71,16 +72,35 @@ class VscMail(object):
     def __init__(
         self,
         mail_host='',
-        mail_port=0,
+        mail_port=587,
         smtp_auth_user=None,
         smtp_auth_password=None,
-        smtp_use_starttls=False):
+        smtp_use_starttls=False,
+        mail_config=None):
+        """
+        - If there is a config file provided, its values take precedence over the arguments passed to __init__
+        - If the mail_host is of the format host:port, that port takes precedence over mail_port
+        """
+
+        mail_options = ConfigParser()
+        if mail_config:
+            logging.info("Reading config file: %s", mail_config)
+            with open(mail_config, "r") as mc:
+                mail_options.read_file(mc)
+
+        # we can have cases where the host part is actually host:port
+        _mail_host = mail_options.get("MAIN", "smtp", fallback=mail_host)
+        try:
+            self.mail_host, _mail_port = _mail_host.split(":")
+        except ValueError:
+            self.mail_host = _mail_host
+            _mail_port = mail_options.get("MAIN", "mail_port", fallback=mail_port)
+
+        self.mail_port = int(_mail_port)
+        self.smtp_auth_user = mail_options.get("MAIN", "smtp_auth_user", fallback=smtp_auth_user)
+        self.smtp_auth_password = mail_options.get("MAIN", "smtp_auth_password", fallback=smtp_auth_password)
+        self.smtp_use_starttls = mail_options.get("MAIN", "smtp_use_starttls", fallback=smtp_use_starttls)
 
-        self.mail_host = mail_host
-        self.mail_port = mail_port
-        self.smtp_auth_user = smtp_auth_user
-        self.smtp_auth_password = smtp_auth_password
-        self.smtp_use_starttls = smtp_use_starttls
 
     def _connect(self):
         """
@@ -95,13 +115,13 @@ class VscMail(object):
             context = ssl.create_default_context()
             s.starttls(context=context)
             logging.debug("Started TLS connection")
+        else:
+            s.connect()
 
         if self.smtp_auth_user and self.smtp_auth_password:
             s.login(user=self.smtp_auth_user, password=self.smtp_auth_password)
             logging.debug("Authenticated")
 
-        s.connect()
-
         return s
 
     def _send(self, mail_from, mail_to, mail_subject, msg):
@@ -119,15 +139,16 @@ class VscMail(object):
             try:
                 s.sendmail(mail_from, mail_to, msg.as_string())
             except smtplib.SMTPHeloError as err:
-                logging.error("Cannot get a proper response from the SMTP host %s", self.mail_host)
+                logging.error("Cannot get a proper response from the SMTP host %s: %s", self.mail_host, err)
                 raise
             except smtplib.SMTPRecipientsRefused as err:
-                logging.error("All recipients were refused by SMTP host %s [%s]", self.mail_host, mail_to)
+                logging.error("All recipients were refused by SMTP host %s [%s]: %s", self.mail_host, mail_to, err)
                 raise
             except smtplib.SMTPSenderRefused as err:
-                logging.error("Sender was refused by SMTP host %s [%s]", self.mail_host, mail_from)
+                logging.error("Sender was refused by SMTP host %s [%s]: %s", self.mail_host, mail_from, err)
                 raise
             except smtplib.SMTPDataError as err:
+                logging.error("Data error: %s", err)
                 raise
 
         except smtplib.SMTPConnectError as err:
